%%%CLOSED_POP_NO_DENSDEP
%%			This program corresponds to the scenario that considers closed local populations and no density-dependence
%%			which was used to evaluate uncertainty in the model structure in:
%%			ANTONIO HERNNDEZ-MATAS, JOAN REAL, MARCOS MOLEN, LUIS PALMA, JOSE ANTONIO SNCHEZ-ZAPATA, ROGER PRADEL, MARTINA CARRETE, JOSE MARA GIL-SNCHEZ,PEDRO BEJA, JAVIER BALBONTN, NICOLAS VINCENT-MARTIN, ALAIN RAVAYROL, JOSE RAMN BENTEZ, BERNARDO ARROYO, CARMELO FERNNDEZ, ERNESTO FERREIRO, JAVIER GARCA
%%			From local monitoring to a broad-scale viability assessment: a case study for the endangered Bonelli's eagle Aquila fasciata in Western Europe 
%%			Ecological Monographs, In Press
%%			 
%%			The program performs a demographic PVA for the Bonelli's Eagle.  
%%			Age-classes are:
%%			(1) chicks; 
%%			(2) juveniles;
%%			(3) immatures;
%%			(4) subadults;
%%			(5) adults.  
%%			The model assumes a post-breeding census, and tracks females only.
%%			 
%%			NOTE: This code has been modified from the original code by Morris and Doak, 2002, Quantitative Conservation Biology, Sinauer Associates, Sunderland, MA.

clear; clear global; rand('state',sum(101*clock)); close all;
dbstop if error

%%Define vital rates
Sr=0.5; %Sex-ratio
%Recruitment rates
R2=0.160762597638242; 
R3=0.679674064762575;
R4=0.934196726;
RA=1;
%Fertilities
F2=0; 
F3=0;
FAmean=0.604900962167398; %adult fertility
FAvar=0.0654735574117504; %environmental variance
FA=[];
for fx99 = 1:99
   FA(fx99)=stretchbetaval(FAmean,sqrt(FAvar),0,2,rand);
   FA=sort(FA);
end;
%Survivals
S1=0.480265629284089;
S2=0.573883441845902;
S3=0.573883441845902;
S4=0.823897173131398;
SAmean=0.882908039493845; %adult survival
SAvar=0.0030304; %environmental variance
SA=[];
for fx99 = 1:99
   SA(fx99)=betaval(SAmean,sqrt(SAvar),rand);
   SA=sort(SA);
end;


n0=[6	4	2	2	20];   % starting population vector in 1990
Nx=1;           % quasi-extinction threshold
tmax=15;        % time horizon (1990-2005)
numreps=10000;   % no. of replicates 


%%%%%******************************************************************************
%%%%%******************************************************************************
%%%%%******************************************************************************
%%code of the simulation

rand('state',sum(100*clock)); % seed random number generator
format long; 

Ns=zeros(1,numreps); %a recipient for results

for rep=1:numreps	% for each replicate, 
   n=n0;			% starting at the initial vector,
   disp(rep);
   for t=1:tmax	% for each year,
      nn(2)=sum(rand(1,n(1))<S1);   % determine no. of birds that survive (by Monte Carlo simulation)
      nn(3)=sum(rand(1,n(2))<S2);   
      nn(4)=sum(rand(1,n(3))<S3);   
      auxnn5_a = sum(rand(1,n(4))<S4);
      auxnn5_b = sum(rand(1,n(5))<SA(round((rand*98)+1)));
      nn(5)=auxnn5_a + auxnn5_b;   
      
      % Calculates the number of potential territorial birds based in recruitment probabilities; 
      %given that we did not constrain the maximum population size, then potential territorials = territorials
      pb=[]; 
      pb(3) = round(nn(3)*R2);
      pb(4) = round(nn(4)*R3);
      pb(5) = round(auxnn5_a*R4);
      pb(6) = auxnn5_b;
      
      %estimate the number of fledglings
      nn(1)=round((pb(3)*(F2*Sr))+(pb(4)*(F3*Sr))+(pb(5)*(FA(round((rand*98)+1))*Sr))+(pb(6)*(FA(round((rand*98)+1))*Sr)));
      
      Npairs=sum(pb); %records the numbers of territorial pairs
      N=sum(nn);               % Sum total population size & 
      Nnonbre=N-Npairs;			%records de number of non-territorials
      pop_fate(t,rep)=Npairs;
      if Npairs<=Nx break; end;     % stop if threshold is hit
      n=nn;                    % replace old vector with the new one
   end; %ends for t
   Ns(rep)=Npairs;                   % Store final population size
end; % ends for rep

%%%Some summary data
ld_aux1 =zeros(1,numreps); %recipient for lambdas
size_aux=size(pop_fate);
   for z=1:size_aux(2)
      for q=1:(size_aux(1)-1)
          if pop_fate(q+1,z)>=Nx
          ld_aux2(q)=pop_fate(q+1,z)./pop_fate(q,z); %save lambdas for one year intervals in recipient 2
          end;
    end;
    ld_aux1(z)=gmean(ld_aux2);
    ld_aux2=[]; %reset recipient 2
 end;
    ld_aux1=sort(ld_aux1);
 
 lambda=mean(ld_aux1);
 ic95_inf=ld_aux1(round((numreps/100)*2.5));
 ic95_sup=ld_aux1(round((numreps/100)*97.5));
 disp('lambda')
 disp(lambda)
 disp('lower 95CI')
 disp(ic95_inf)
 disp('upper 95CI')
 disp(ic95_sup)
 
 
 %Have a look on the results
figure(1)
ARR1=plot(pop_fate);
axis([0 tmax 5 30])
xlabel('Time','FontSize',14)
ylabel('No. territorial pairs','FontSize',14)
set( gca                      ,...
   'Ticklength',	[.02 .02]	,...
   'Linewidth' ,	1.5				,...
   'FontSize'	,	14);


%Average trend
inv_pop_fate=sort(pop_fate');
  mean_pop_fate=[];
  mean_pop_fate(1,:)=inv_pop_fate(round((numreps/100)*2.5),:);
  mean_pop_fate(2,:)=mean(inv_pop_fate);
  mean_pop_fate(3,:)=inv_pop_fate(round((numreps/100)*97.5),:);
  
  aux_axis=[1:tmax];

figure(2)
ARR2=plot(aux_axis,mean_pop_fate([1 3],:)','b--',aux_axis,mean_pop_fate(2,:),'b-')
axis([0 tmax 5 30])
xlabel('Time','FontSize',14)
ylabel('Mean no. territorial pairs','FontSize',14)
set( gca                      ,...
   'Ticklength',	[.02 .02]	,...
   'Linewidth' ,	1.5				,...
   'FontSize'	,	14);
set( ARR2   ,...
   'Color'	,	[0 0 0],...
   'Linewidth' ,	1.5);


