%%%MULTISITE_CONS_10pop
%%			This program corresponds to the constrained scenario used for the viability assessment (10 local populations) in the manuscript
%%			ANTONIO HERNNDEZ-MATAS, JOAN REAL, MARCOS MOLEN, LUIS PALMA, JOSE ANTONIO SNCHEZ-ZAPATA, ROGER PRADEL, MARTINA CARRETE, JOSE MARA GIL-SNCHEZ,PEDRO BEJA, JAVIER BALBONTN, NICOLAS VINCENT-MARTIN, ALAIN RAVAYROL, JOSE RAMN BENTEZ, BERNARDO ARROYO, CARMELO FERNNDEZ, ERNESTO FERREIRO, JAVIER GARCA
%%			From local monitoring to a broad-scale viability assessment: a case study for the endangered Bonelli's eagle Aquila fasciata in Western Europe 
%%			Ecological Monographs, In Press
%%			 
%%			The program simulates the demographic trends of several local populations (NumPop) connected by migration; 
%%			dispersal probabilities have to be defined (DISP); 
%%			under constrained dispersal, once an individual 'decides' to settle in a given
%%			local population (on the basis of recruitment rates and dispersal kernels), it remains there, independently of whether or not a site 
%%			is available. Experienced breeders are not allowed to disperse.
%%			Vital rates are provided in the same order than the local populations were coded in the manuscript:
%%			1	ANR_BUR
%%			2	ARA_E_CLM
%%			3	ARR_ARRPT
%%			4	AND
%%			5	PVAL
%%			6	CAT
%%			7	FRA
%%			8	MUR
%%			9	POR SW
%%			10	EXT_W_CLM
%%			
%%			It is a female only model and it is based in a post-breeding census
%%			Time steps correspond to years
%%			Density-dependence was incorporated into the model by fixing an absolute maximum for the number of breeding pairs that 
%%			each population can sustain (i.e. the carrying capacity, K)
%%			The life-cycle considers 5 age-classes (survivals, fertilities, recruitment rates);
%%			however, the model actually shows 6 age-classes; this was done to keep first-year adults (5th age-class) and older adults (6th age-class) in 
%%			different age categories and to 
%%			manage adequately the recruitment process of philopatric and migrating individuals (see code below)
%%			
%%			NOTE: the code was written by Antonio Hernndez-Matas and it was initially based in the code developed by Morris and Doak, 2002, Quantitative Conservation Biology, Sinauer Associates, Sunderland, MA.
%%			 for a single population  

clear; clear global; rand('state',sum(101*clock)); close all;
dbstop if error

%define some global parameters
NumPop=10;			%number of local populations
ageclass=6;			%number of age-classes
Nx=50;           % quasi-extinction threshold
tmax=50;        % time horizon
numreps=10000;   % no. of replicates 

%Vital rates that are shared by all local populations
Sr=0.5; %Sex-ratio
RB= [0.16076 0.67967 0.93419 1]; %ratio of territorials: expected ratio of territorial birds in any given age class from 2 year-old to 5 year-old and older birds (these probabilities apply in t)
RR = [0.160762598	0.618313085	0.794574005	1]; %recruitment rate: probability that a non-territorial bird of any given age will try to settle as territorial (these probabilities apply in the time step from t-1 to t)
%This measurements of recruitment are based in the calculations from Hernndez-Matas et al. 2010. Determinants of Territorial Recruitment in Bonellis Eagle (Aquila fasciata) Populations. Auk 127:173184. 
%and the transformations developed by Pradel and Lebreton. 1999. Comparison of different approaches to the study of local recruitment of breeders. Bird Study 46:7481

%%Set initial population sizes and carrying capacities
%%initial population sizes are based in the 2005 censuses, the stable age distribution and the expected number of non-territorial birds of territorial ages
n0=[5	3	3	2	2	10; 
39	19	13	8	7	73;
9	5	3	3	3	26;
352	218	146	99	89	447;
48	24	16	10	9	76;
35	18	11	6	5	54;
14	7	4	3	3	23;
13	7	4	3	3	17;
33	21	15	11	10	62;
60	29	17	10	9	115];
%carrying capacity
K=[52	116	68	365	103	85	36	42	95	140]; 

%dispersals probabilities, rows are local populations of origin and columns are destination local population, the diagonal is the probability of non-dispersal
%%POWER LAW, AVERAGE
DISP=[0.6059	0.2257	0.0187	0.0196	0.0409	0.0598	0.0035	0.0013	0.0046	0.02	;
0.0143	0.5319	0.0052	0.1088	0.1397	0.1114	0.0068	0.0173	0.0092	0.0553	;
0.007	0.0257	0.6098	0.036	0.0055	0.006	0.0021	0.0013	0.0734	0.2331	;
0.0015	0.0373	0.0048	0.7553	0.0357	0.0128	0.0045	0.025	0.0315	0.0916	;
0.006	0.1297	0.0029	0.1075	0.5764	0.1049	0.0044	0.0303	0.0076	0.0303	;
0.012	0.1452	0.0019	0.0217	0.1693	0.5875	0.0411	0.0066	0.0049	0.0097	;
0.0014	0.012	0.0015	0.0166	0.0092	0.2093	0.7385	0.0011	0.0039	0.0066	;
0.0014	0.0666	0.0034	0.4103	0.0923	0.0163	0.0041	0.3555	0.0088	0.0414	;
0.0009	0.0078	0.016	0.1343	0.0073	0.008	0.0028	0.0017	0.6464	0.1748	;
0.0019	0.0335	0.026	0.1922	0.0216	0.0146	0.0051	0.0056	0.0894	0.6103	];
     
%%some related matrix useful when modeling the dispersal process
ATR=DISP;
%%ATR2 is useful for dispersers only
ATR2=ATR;
for i=1:NumPop  
   if (ATR(i,i)==1)
      ATR2(i,:)=zeros(1,NumPop);
   else
      ATR2(i,i)=0; 
   	ATR2(i,:)=ATR2(i,:)/sum(ATR2(i,:)); end;
end;

%%%Set the values of vital rates of local populations
%non adult survivals
S=[0.480265629	0.573883442	0.573883442	0.852787792;
0.480265629	0.573883442	0.573883442	0.84721551;
0.480265629	0.573883442	0.573883442	0.823897173;
0.662946429	0.719975512	0.719975512	0.863880874;
0.480265629	0.573883442	0.573883442	0.809977369;
0.480265629	0.573883442	0.573883442	0.829643268;
0.480265629	0.573883442	0.573883442	0.821163142;
0.480265629	0.573883442	0.573883442	0.833061745;
0.662946429	0.719975512	0.719975512	0.874833159;
0.480265629	0.573883442	0.573883442	0.874833159];

%adult survivals and environmental variances
SAmean=[0.913867922	0.907896531	0.882908039	0.925755536	0.867991242	0.889065693	0.879978186	0.892729015	0.937492268	0.923638943]; 
SAvar=[0.002595742	0.000693942	0.0030304	0.000655006	0.003180415	0.001281247	0.002070305	0.001656961	0.000555761	0.000622246];
SA=[];
for NP=1:NumPop
   for fx99 = 1:99
	valaux=betaval(SAmean(NP),sqrt(SAvar(NP)),rand);
   SA(NP,fx99)=valaux;
end;
SA=sort(SA')';
end;

%non-adult fertilities
 FNA=[0.00000000	0.00000000;
0.28571429	0.30769231;
0.00000000	0.00000000;
0.28571429	0.61470588;
0.28571429	0.80000000;
0.28571429	0.40000000;
0.45388889	0.45388889;
0.28571429	0.51041667;
0.28571429	0.50000000;
0.28571429	0.33333333];

%adult fertilities and environmental variances
FAmean=[0.731309765	0.8842485	0.604900962	1.231149291	1.046406422	1.129109343	0.978656511	1.201271966	0.830328235	0.93572236];
FAvar=[0.05465705	0.052814006	0.065473557	0.041248755	0.064705219	0.02451698	0.045392109	0.060759509	0.032828738	0.05510211];
FA=[];
for NP=1:NumPop
   for fx99 = 1:99
   valaux=stretchbetaval(FAmean(NP),sqrt(FAvar(NP)),0,2,rand);
   FA(NP,fx99)=valaux;
end;
FA=sort(FA')';
end;

ratios_no_pb=[0.5008    0.1449    0.0301         0; %this matrix is only used in t==1 to correct for the number of non-territorial birds (values estimated from the results of 18 population models)    
   0.9983    0.8178    0.2697         0;
    0.5904    0.1960    0.0398         0;
    0.8623    0.3654    0.0826         0;
    0.9945    0.7874    0.2504         0;
    0.9950    0.7296    0.2063         0;
    0.7813    0.3088    0.0630         0;
    0.9628    0.5275    0.1214         0;
    0.8176    0.2952    0.0608         0;
    0.7850    0.2433    0.0584         0];


%%%%%******************************************************************************
%%%%%******************************************************************************
%%%%%******************************************************************************
%%code of the simulation

rand('state',sum(100*clock)); % seed random number generator

%predefine some recipients for results
Ns=zeros(1,numreps);
No_breed=zeros(1,numreps);
Nt=zeros(1,numreps);

for rep=1:numreps	% for each replicate  
      disp(rep);
      n=n0;			% starting at the initial vector,
      
for t=1:tmax	% for each year,
   
%%	overall numbers of birds are stored in n and nn, in t-1 and t respectively
   
%%	numbers of birds in "territorial ages" (those that based in their age can be potentially territorial) are stored into three matrices:
%% (1) nb and nnb1 describe the numbers of territorials, in t-1 and t respectively
%% (2) no_pb_t0 and no_nnb1 describe the numbers of non-territorials that have not attempted to recruit as 
%% territorial (based in the recruitment probabilities), in t-1 and t respectively
%% (3) pb_no_bre_t0 and pb_no_bre describe the numbers of individuals that attempted to be territorial but that failed to recruit because of 
%% territory availability, in t-1 and t respectively

 			if t==1; %%this 'if' is required to create nb (number of territorial birds), no_pb_t0 (numbers of non-territorial birds that did not attempt  
             %%to recruit) and pb_no_bre_t0 (attempted to recruit but failed because of site availability) in t==1; 
             %%within this 'if' only birds in recruitable ages are considered
            %%in the model it works as if these numbers had resulted from the previous time step (t=0) which is not computed actually;
            nb=zeros(NumPop,4);%%% Number of territorial birds
			for i=1:NumPop %for each local population      
         	pb_aux(i,:)=round(n(i,3:6).*RB);  %number of potential territorials based in the number of individuals in any given age-class and 
         												%the corresponding ratio of territorial birds in that age-class
         	for bckw=0:3	%to give settlement priority to older individuals
					K_aux=K(i)-sum(nb(i,:));		%an auxiliar vector that tracks the availability of territoriies
					pos=4-bckw;
					if(pb_aux(i,pos) <= K_aux) nb(i,pos)=pb_aux(i,pos);
					else nb(i,pos) = K_aux; end;
					if sum(nb(i,:))>=K(i) break;end;
            end;
         end;
         no_pb_t0_aux=n(:,3:6)-nb; 						%%this is to split non-territorial individuals into two groups: those that do not attempt to recruit and those that attempted to recruit but that have not a site 
         no_pb_t0=floor(no_pb_t0_aux.*ratios_no_pb);  %%numbers of non-territorial birds in recruitable ages
         pb_no_bre_t0=n(:,3:6)-nb-no_pb_t0;  %%no_pb_t0 son bitxos q no es volen reproduir de les edats reproductores, mentre que pb_no_bre_t0 son bitxos que intenten per no poden reproduirse
         end; %end if
                  
%%estimate territorials which survive
for i=1:NumPop  
for j=1:2 %immatures is postion 1, subadults position 2, first year adults position 3, older adults position 4
   nnb1(i,j+1)=sum(rand(1,nb(i,j))<S(i,j+2));
end;
	SA_aux(i)=SA(i,round((rand*98)+1)); 	%picks a random value of survival for any given population
   ad1_nnb(i)=sum(rand(1,nb(i,3))<SA_aux(i)); %position 3 in nb (e.g. first year adult birds)
   ad2_nnb(i)=sum(rand(1,nb(i,4))<SA_aux(i)); %position 4 in nb (e.g. experienced adult birds)
	nnb1(i,4)=ad1_nnb(i)+ad2_nnb(i);   
end;

%%estimate non-territorials that did not attempt to recruit in t-1 (from recruitable age-classes) which survive
for i=1:NumPop 
for j=1:2 %immatures is postion 1, subadults position 2, first year adults position 3, older adults position 4
   no_nnb1(i,j+1)=sum(rand(1,no_pb_t0(i,j))<S(i,j+2));
end;
   ad1_no_nnb(i)=sum(rand(1,no_pb_t0(i,3))<SA_aux(i)); 
   ad2_no_nnb(i)=sum(rand(1,no_pb_t0(i,4))<SA_aux(i)); 
	no_nnb1(i,4)=ad1_no_nnb(i)+ad2_no_nnb(i);   
end;

%%estimate non-territorials that failed to recruit because of site availability in t-1 which survive
for i=1:NumPop 
for j=1:2 %immatures is postion 1, subadults position 2, first year adults position 3, older adults position 4
   pb_no_bre(i,j+1)=sum(rand(1,pb_no_bre_t0(i,j))<S(i,j+2));
end;
   ad1_pb_no_bre(i)=sum(rand(1,pb_no_bre_t0(i,3))<SA_aux(i)); 
   ad2_pb_no_bre(i)=sum(rand(1,pb_no_bre_t0(i,4))<SA_aux(i)); 
	pb_no_bre(i,4)=ad1_pb_no_bre(i)+ad2_pb_no_bre(i);   
end;

%%estimate chicks and youngs in t-1 which survive to t (respectively, non-breeders of ages 1 year(juvenile) and 2 years(immatures) in t) 
for i=1:NumPop 
   for j=2:3
   nn(i,j)=sum(rand(1,n(i,j-1))<S(i,j-1));
end;
end;

%%fill the nn matrix with the numbers of birds in recruitable ages that are non-territorials to date
for i=1:NumPop 
   no_nnb1(i,1)=nn(i,3);
end;

%%estimate availability of sites for territorial recruitment
aval_abs=(K-sum(nnb1'));
aval_abs(find(aval_abs<0))=0;

%%%some previous calculations to later calculate the number of territorial birds
for i=1:NumPop %estimate potential territorials from birds without previous territorial experience (based in the recruitment probability) 
   for y=1:4 %for each age class
   pb(i,y)=sum(rand(1,no_nnb1(i,y))<RR(y)); %records potential territorials
end;
   no_pb(i,:)=no_nnb1(i,:)-pb(i,:); %records the number of birds in territorial age, but that will not attempt to recruit
end;

%%estimate potential philopatric individuals (pr): a fraction of potential territorials (pb) that will try to settle in their population of origin
for i=1:NumPop  
   for y=1:4
         pr(i,y)=sum(rand(1,pb(i,y))<ATR(i,i));
end;
end;

%%pb_no_bre attempt to recruit (birds that attempted to recruit in t-1 but that failed and that were already in the population where they attempt to recruit)
for i=1:NumPop 
      for bckw=0:3 %older individuals are allowed to recruit first than younger ones
         pos=4-bckw;
         if pb_no_bre(i,pos)<aval_abs(i);  %%if there is site availability for pb_no_bre
            aval_abs(i) =aval_abs(i)-pb_no_bre(i,pos); %%availability is reduced
            pb_exp(i,pos)=pb_no_bre(i,pos); %%pb_no_bre that have a site go into pb_exp
            pb_no_bre(i,pos)=0; %%and discounted from pb_no_bre
         else %if there is no enough site availability for all pb_no_bre
            pb_exp(i,pos)=aval_abs(i); %only those for which there is site availability go into pb_exp
            pb_no_bre(i,pos)=(pb_no_bre(i,pos)-aval_abs(i));   %and all others remain in pb_no_bre
            aval_abs(i)=0; %and there is no any more site availability in that population
         end; %end if
   end; end; %ends fors

%potential philopatric individuals attempt to recruit (birds that attempt to recruit for the first time in their life) and 
%potential dispersers pd (birds that will try to recruit in another population) are calculated
%if there is no site availability pr remain in the population of origin as pb_no_bre
for i=1:NumPop 
      for bckw=0:3  %older individuals are allowed to recruit first than younger ones
         pos=4-bckw;
         if pr(i,pos)<aval_abs(i);  %%if there is site availability for pr
            aval_abs(i) =aval_abs(i)-pr(i,pos); %%availability is reduced
            pd(i,pos)=pb(i,pos)-pr(i,pos); %%calculate potential dispersers
            pb_no_bre(i,pos)=pb_no_bre(i,pos); %%potential philopatric individuals non-allocated (because lack of sites)
         else
            pb_no_bre(i,pos)=pb_no_bre(i,pos)+(pr(i,pos)-aval_abs(i));   %those pr for which there is no site availability come back to pb_no_bre
            pd(i,pos)=pb(i,pos)-pr(i,pos); %%calculate potential dispersers
            pr(i,pos)=aval_abs(i); %only those individuals for which there is site availability remain in pr
            aval_abs(i)=0; %and there is no any more site availability in that population
         end; %end if
   end; end; %ends fors

%%decide where potential dispersers try to settle 
pin=zeros(NumPop,4); %%a recipient for potential inmigrants
for i=1:NumPop %for each population of origin
   if ATR(i,i)<1 %%if all individuals are philopatric it is not required to execute all this
	ATR_aux=ATR2(i,:); %%creates a vector with the probabilities of dispersing to any given population 
   ATR_aux(i)=[];  %%except the population of origin
   roulette = cumsum(ATR_aux); %%%a vector with cumulative probabilities to assing potential dispersers to destination populations
   terr_age=1:4; %older individuals are allowed to recruit first than younger ones
   back_age=terr_age(length(terr_age):-1:1);
   for y=back_age %for any given age class (in inverse order)
      v_pin_aux=zeros(1,NumPop-1); %%its shorter because the population of origin is not in the roulette
         for ii=1:pd(i,y) %for each individual of any given age and population of origin
         rnd_num=rand;
         if (rnd_num>0.99) rnd_num=0.99; end; %to avoid rnd_num takes value 1 
            pop_dest = find( rnd_num <= roulette );
		   	pop_dest = pop_dest(1);   
            v_pin_aux(pop_dest)=v_pin_aux(pop_dest)+1;
         end;
         if (i==1) %%put 0 inmigrants in the position of the population of origin
         	v_pin_aux=[0,v_pin_aux]; 
      	else
            v_pin_aux=[v_pin_aux(1:(i-1)),0,v_pin_aux(i:end)]; 
         end; 
         
         for j=1:NumPop %%for each destination population
        	if v_pin_aux(j)<aval_abs(j); %if the number of potential inmigrants is lower than site availability
            pin(j,y)=pin(j,y)+v_pin_aux(j); %fills the matrix of potential inmigrants
            aval_abs(j) =aval_abs(j)-v_pin_aux(j); %reduces site availability
            pd(i,y)=pd(i,y)-v_pin_aux(j); %and discount already dispersed birds from potential dispersers
         else
            pin(j,y)=pin(j,y)+aval_abs(j); %if there is not enough site availability only go into potential inmigrants those for which there is site availability
            pd(i,y)=pd(i,y)-aval_abs(j); %discount already dispersed birds from potential dispersers
            pb_no_bre(j,y)=pb_no_bre(j,y)+(v_pin_aux(j)-aval_abs(j)); %%inmigrants aiming to recruit for which there is no site availability go into pb_no_bre
				aval_abs(j)=0;  %and there is no any more site availability in that population
         end;
      end; %ends loop for destiny population
      end; %ends backage
      end; %ends if
end; %ends population of origin  

   
%%calculate birds without previous experience that will try to breed on each population
pb2=pr+pin+pb_exp;
%%recalculate population numbers after migration of potential breeders
new_nn=nnb1+pb2+no_pb+pb_no_bre;
nn(:,3:ageclass)=new_nn;
      
%%calculate the number of breeders
nnb=nnb1+pb2; 
%records de number of  non-breeders
no_nnb=nn(:,3:6)-nnb;			
      
      
%%calculate productivities
for i=1:NumPop %per cada poblaci      
     nn(i,1)=round((nnb(i,1)*(FNA(i,1)*Sr))+(nnb(i,2)*(FNA(i,2)*Sr))+(nnb(i,3)*(FA(i,round((rand*98)+1))*Sr))+(nnb(i,4)*(FA(i,round((rand*98)+1))*Sr)));
end;

%% records total numbers of birds         
		Npairs=sum(sum(nnb)); %records the total numbers of territorial pairs
      Npairs_pop=sum(nnb');
      N_pb_no_bre_pops=sum(pb_no_bre'); %%records the total number of potential breeders at each population that do not bred, because K
      N=sum(sum(nn));               % Sum total population size & 
      Nnonbre=N-Npairs;			%records de total number of non-breeder
      
 %% records local population fates
      pop_fate(t,rep)=Npairs;
      for i=1:NumPop %per cada poblaci      
          pop_fate_pops(t,rep,i)=Npairs_pop(i);
          pop_fate_pops_pb_no_bre(t,rep,i)=N_pb_no_bre_pops(i);
      end;
      if Npairs<=Nx break; end;     % stop if threshold is hit.

        
  %%%replace old vectors with newones
      nb=nnb;
      no_nb=no_nnb;            
      n=nn;                    
   
	   pb_no_bre_t0=pb_no_bre; %keep the count of potential territorial birds that did not find a site to recruit 
	   no_pb_t0=no_pb;			%from those birds of 'territorial ages' that did not attempt to recruit
            
            
  %reset other recipients
      nn=[];
      nnb=[];
      no_nnb=[];
      nnb1=[];
      no_nnb1=[];
      pb=[];
      no_pb=[];
      pr=[];
      pd=[];
      pin=[];
      pb_no_bre=[];
      pb_exp=[];
            
end; %%%%%%%%ends for t

% Store final population size
Ns(rep)=Npairs;                   
No_breed(rep)=Nnonbre;
Nt(rep)=N;

end; % ends for rep

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%ends the code of the simulation



%%%Some summary data

 %%Get average population fate 
 inv_pop_fate=sort(pop_fate');
 mean_pop_fate=[];
 mean_pop_fate(1,:)=inv_pop_fate(round((numreps/100)*2.5),:);
 mean_pop_fate(2,:)=mean(inv_pop_fate);
 mean_pop_fate(3,:)=inv_pop_fate(round((numreps/100)*97.5),:);

 %%%Estimate local population lambdas; only considers the period before extinction, irrespectively if after the population is recolonized
  lambdas_pop=zeros(NumPop,4);
    for i=1:NumPop
	ld_aux1 =zeros(1,numreps); %recipient for lambdas
	size_aux=size(pop_fate_pops(:,:,i));  %auxiliar vector for local population fates
		for z=1:size_aux(2)
   	vaux=pop_fate_pops(:,z,i)'; %another auxiliar recipient for local population fates
   	if sum(vaux==0)>0 %if extincition is done, then only consider the period before extinction
      vaux2=vaux(1:min(find(vaux==0)))+1; 
   	else
      vaux2=vaux;
   	end;
   	l_vaux=length(vaux2);
      	for q=1:(l_vaux-1)
          ld_aux2(q)=vaux2(q+1)./vaux2(q); %save lambdas for one year intervals in recipient 2
    		end;
    	ld_aux1(z)=gmean(ld_aux2); %geometric mean of lambdas (for each replicate)
    	ld_aux2=[]; %reset recipient 2
 		end;
   ld_aux1=sort(ld_aux1); %sort the vector with the values of lambdas for each replicate
          
 lambda=mean(ld_aux1); %mean lambda
 ic95_inf=ld_aux1(round((numreps/100)*2.5)); %95% percetile range
 ic95_sup=ld_aux1(round((numreps/100)*97.5));
 lambda_median=median(ld_aux1); %median
 
 lambdas_pop(i,1)=lambda; %records lambda summaries
 lambdas_pop(i,2)=ic95_inf;
 lambdas_pop(i,3)=ic95_sup;
 lambdas_pop(i,4)=lambda_median;
 end; %ends initial for

%%%Estimate overall population lambda
ld_aux1 =zeros(1,numreps); %recipient for lambdas
size_aux=size(pop_fate);
   for z=1:size_aux(2)
      for q=1:(size_aux(1)-1)
          if pop_fate(q+1,z)>=Nx
          ld_aux2(q)=pop_fate(q+1,z)./pop_fate(q,z); %save lambdas for one year intervals in recipient 2
          end;
    end;
    ld_aux1(z)=gmean(ld_aux2);
    ld_aux2=[]; %reset recipient 2
 end;
    ld_aux1=sort(ld_aux1);
 
 lambda=mean(ld_aux1);
 ic95_inf=ld_aux1(round((numreps/100)*2.5));
 ic95_sup=ld_aux1(round((numreps/100)*97.5));
 disp('lambda')
 disp(lambda)
 disp('lower 95CI')
 disp(ic95_inf)
 disp('upper 95CI')
 disp(ic95_sup)
 

%%%%SAVE MAIN RESULTS
%save MET10_CONS_POW pop_fate mean_pop_fate pop_fate_pops lambda ic95_inf ic95_sup lambdas_pop 

 %Have a look on the overall trend
 aux_axis=[1:tmax];
 figure(1)
 plot(aux_axis,mean_pop_fate([1 3],:)','b--',aux_axis,mean_pop_fate(2,:),'b-')
 axis([0 tmax 1 1200])
 xlabel('Time','FontSize',14)
 ylabel('No. territorial pairs','FontSize',14)

  
 %and on local trends
 inv_pop_fate=sort(pop_fate_pops(:,:,1)');
 mean_pop_fate_p=[];
 mean_pop_fate_p(1,:)=inv_pop_fate(round((numreps/100)*2.5),:);
 mean_pop_fate_p(2,:)=mean(inv_pop_fate);
 mean_pop_fate_p(3,:)=inv_pop_fate(round((numreps/100)*97.5),:);
 figure(2)
 plot(aux_axis,mean_pop_fate_p([1 3],:)','b--',aux_axis,mean_pop_fate_p(2,:),'b-')
 axis([0 tmax 0 100])
 xlabel('Time','FontSize',14)
 ylabel('No. territorial pairs','FontSize',14)





