%%%MULTISITE_CONS_18pop
%%			This program corresponds to the constrained scenario used to evaluate uncertainty in the model structure and 
%%			in the natal dispersal kernel (18 local populations) in:
%%			ANTONIO HERNNDEZ-MATAS, JOAN REAL, MARCOS MOLEN, LUIS PALMA, JOSE ANTONIO SNCHEZ-ZAPATA, ROGER PRADEL, MARTINA CARRETE, JOSE MARA GIL-SNCHEZ,PEDRO BEJA, JAVIER BALBONTN, NICOLAS VINCENT-MARTIN, ALAIN RAVAYROL, JOSE RAMN BENTEZ, BERNARDO ARROYO, CARMELO FERNNDEZ, ERNESTO FERREIRO, JAVIER GARCA
%%			From local monitoring to a broad-scale viability assessment: a case study for the endangered Bonelli's eagle Aquila fasciata in Western Europe 
%%			Ecological Monographs, In Press
%%			
%%			The program simulates the demographic trends of several local populations (NumPop) connected by migration; 
%%			dispersal probabilities have to be defined (DISP); 
%%			under constrained dispersal, once an individual 'decides' to settle in a given
%%			local population (on the basis of recruitment rates and dispersal kernels), it remains there, independently of whether or not a site 
%%			is available. Experienced breeders are not allowed to disperse.
%%			Vital rates are provided in the same order than the local populations were coded in the manuscript:
%%			1	ANR
%%			2	ARA
%%			3	ARR
%%			4	BUR
%%			5	CAD
%%			6	CAS
%%			7	CAT
%%			8	FRA
%%			9	GRA
%%			10	GUA
%%			11	MUR
%%			12	SWP
%%			13	EXT-WCLM
%%			14	NPT
%%			15	Rest of AND
%%			16	Rest of PVAL
%%			17	Rest of ECLM
%%			18	Rest of SPT
%%			
%%			It is a female only model and it is based in a post-breeding census
%%			Time steps correspond to years
%%			Density-dependence was incorporated into the model by fixing an absolute maximum for the number of breeding pairs that 
%%			each population can sustain (i.e. the carrying capacity, K)
%%			The life-cycle considers 5 age-classes (survivals, fertilities, recruitment rates);
%%			however, the model actually shows 6 age-classes; this was done to keep first-year adults (5th age-class) and older adults (6th age-class) in 
%%			different age categories and to 
%%			manage adequately the recruitment process of philopatric and migrating individuals (see code below)
%%			
%%			NOTE: the code was written by Antonio Hernndez-Matas and it was initially based in the code developed by Morris and Doak, 2002, Quantitative Conservation Biology, Sinauer Associates, Sunderland, MA.
%%			 for a single population


clear; clear global; rand('state',sum(101*clock)); close all;
dbstop if error

%define some global parameters
NumPop=18;			%number of local populations
ageclass=6;			%number of age-classes
Nx=50;           % quasi-extinction threshold
tmax=15;        % time horizon
numreps=10000;   % no. of replicates for prob.(ext.) calculation

%Vital rates that are shared by all local populations
Sr=0.5; %Sex-ratio
RB= [0.16076 0.67967 0.93419 1]; %ratio of territorials: expected ratio of territorial birds in any given age class from 2 year-old to 5 year-old and older birds (these probabilities apply in t)
RR = [0.160762598	0.618313085	0.794574005	1]; %recruitment rate: probability that a non-territorial bird of any given age will try to settle as territorial (these probabilities apply in the time step from t-1 to t)
%This measurements of recruitment are based in the calculations from Hernndez-Matas et al. 2010. Determinants of Territorial Recruitment in Bonellis Eagle (Aquila fasciata) Populations. Auk 127:173184. 
%and the transformations developed by Pradel and Lebreton. 1999. Comparison of different approaches to the study of local recruitment of breeders. Bird Study 46:7481

%%Set initial population sizes and carrying capacities
%%initial population sizes are based in the 1990 censuses and the stable age distribution 
n0=[6	3	2	1	1	14;
21	11	7	4	3	40;
6	4	2	2	2	18;
4	2	1	1	1	10;
25	15	10	7	6	28;
14	7	5	3	2	24;
42	21	13	8	7	64;
14	7	4	3	2	24;
29	18	13	9	8	30;
13	7	4	3	3	21;
12	6	4	2	2	17;
10	7	5	3	3	19;
57	28	16	10	9	109;
6	3	2	2	2	17;
127	79	53	36	31	175;
34	17	11	7	6	53;
16	8	5	3	3	34;
6	4	3	2	2	11];
%carrying capacity
K=[28	46	24	24	44	31	85	36	59	26	42	53	140	44	262	72	44	42]; 
%%carrying capacity to be used in SCENARIOS 3 and 4
%K=[7	31	11	3	42	28	65	28	54	14	22	38	127	20	238	65	40	30];; %corresponds to 2005 census



%dispersals probabilities, rows are local populations of origin and columns are destination local population, the diagonal is the probability of non dispersal
%%EXPONENTIAL, AVERAGE
%DISP=[0.59114393	0.21645387	0.00252438	0.03872486	0.00049770	0.01046837	0.04097876	0.00094580	0.00063990	0.05435900	0.00026070	0.00056880	0.00490043	0.00152475	0.00282030	0.01015245	0.02268050	0.00035550;
%0.02765266	0.42248628	0.00043380	0.00151278	0.00056198	0.08847967	0.27725900	0.00372914	0.00082423	0.04277314	0.00282140	0.00064226	0.00935726	0.00024536	0.00489233	0.06999221	0.04593507	0.00040141;
%0.00170262	0.00099068	0.32594808	0.00134408	0.00050433	0.00033622	0.00122481	0.00043229	0.00064843	0.00870434	0.00026417	0.00268816	0.24511652	0.33642617	0.01058023	0.00078052	0.00363967	0.05866868;
%0.58136409	0.06254067	0.01542907	0.26046690	0.00042447	0.00092325	0.00318364	0.00036383	0.00054574	0.03202717	0.00022234	0.00048510	0.01085810	0.01291967	0.00240531	0.00087299	0.01466447	0.00030319;
%0.00021286	0.00065985	0.00029800	0.00004257	0.35323898	0.00059600	0.00217113	0.00076628	0.06182116	0.00029800	0.00295849	0.02250235	0.03533161	0.00034057	0.50787268	0.00138357	0.00343933	0.00606657;
%0.00674887	0.09457498	0.00021700	0.00009305	0.00065101	0.32156015	0.25387370	0.00170150	0.00276787	0.01546358	0.01300484	0.00074401	0.00717992	0.00024800	0.01735021	0.20806880	0.05528750	0.00046500;
%0.00657562	0.10935419	0.00017471	0.00009541	0.00052412	0.10832379	0.64532375	0.03670159	0.00067386	0.00731261	0.00184428	0.00059899	0.00205258	0.00019966	0.00314186	0.05886384	0.01786477	0.00037437;
%0.00033676	0.00359624	0.00013618	0.00001945	0.00040855	0.00185442	0.15212771	0.83511030	0.00052528	0.00013618	0.00021400	0.00046692	0.00128402	0.00015564	0.00231513	0.00063228	0.00038910	0.00029182;
%0.00025009	0.00083234	0.00035013	0.00005002	0.03379550	0.00193880	0.00255095	0.00090033	0.33472792	0.00163954	0.02465301	0.00339664	0.06267911	0.00040015	0.48018523	0.02125490	0.02805660	0.00233873;
%0.02182801	0.10504498	0.00283780	0.00126653	0.00098605	0.01694954	0.01664003	0.00084518	0.00296946	0.48250011	0.00184812	0.00112691	0.07393618	0.00185652	0.01630614	0.03953332	0.21218113	0.00134399;
%0.00022215	0.00171156	0.00031102	0.00004443	0.00385040	0.00937726	0.00388009	0.00079976	0.06663484	0.00178338	0.33200329	0.00106634	0.01962003	0.00035545	0.39410334	0.09518672	0.06838349	0.00066646;
%0.00015217	0.00047172	0.00077623	0.00003043	0.02178797	0.00042607	0.00155211	0.00054780	0.00436535	0.00021303	0.00033477	0.64716539	0.05696189	0.00060565	0.06412777	0.00098909	0.00060867	0.19888391;
%0.00034183	0.00150751	0.01403695	0.00008201	0.00845216	0.00139711	0.00290157	0.00100471	0.01434339	0.00615609	0.00222501	0.01759738	0.68195330	0.01151617	0.14733834	0.00562827	0.01454211	0.06897609;
%0.00132068	0.00046018	0.28085877	0.00115911	0.00048012	0.00032008	0.00116601	0.00041153	0.00061730	0.00577430	0.00025149	0.00234746	0.20991507	0.41402898	0.00597422	0.00074305	0.00223400	0.07193762;
%0.00025184	0.00090141	0.00071216	0.00005037	0.06301641	0.00237763	0.00258986	0.00090663	0.13488795	0.00179155	0.03090967	0.00980635	0.07680505	0.00054353	0.62735083	0.01636100	0.02528543	0.00545234;
%0.00100014	0.02238206	0.00028946	0.00004482	0.00086837	0.10116004	0.04545488	0.00074432	0.01336209	0.00765361	0.04081993	0.00099243	0.01257244	0.00033081	0.05703544	0.57982275	0.11484616	0.00062027;
%0.00203152	0.02205210	0.00081143	0.00023105	0.00305915	0.03045144	0.01786981	0.00104642	0.03349099	0.07383319	0.03742351	0.00139522	0.05148168	0.00065232	0.14117369	0.15889617	0.42311207	0.00098823;
%0.00015696	0.00048657	0.01568755	0.00003139	0.00800069	0.00043948	0.00160097	0.00056505	0.00404008	0.00102941	0.00034531	0.11067680	0.36074899	0.01488870	0.04781777	0.00102022	0.00103551	0.43142854];

%%POWER LAW, AVERAGE
DISP=[0.54674812	0.16099465	0.00665906	0.03467481	0.00252527	0.01948538	0.06931854	0.00377503	0.00324678	0.04990065	0.00132276	0.00288602	0.01729908	0.00479274	0.01430986	0.02810668	0.03215080	0.00180376;
0.02189493	0.39909712	0.00171027	0.00288513	0.00285141	0.07301276	0.24227034	0.00986972	0.00400285	0.03295321	0.00969617	0.00325875	0.02931344	0.00118822	0.02150002	0.08566900	0.05678995	0.00203672;
0.00475628	0.00382382	0.32350563	0.00264350	0.00255893	0.00170595	0.00621454	0.00219337	0.00329005	0.01730092	0.00134039	0.00953801	0.23787387	0.27570111	0.03711362	0.00396025	0.00836883	0.05811091;
0.43666000	0.07528393	0.02810920	0.29163263	0.00215369	0.00356652	0.01239612	0.00184602	0.00276903	0.03998833	0.00112812	0.00246136	0.03337402	0.02700903	0.01220424	0.00405238	0.02382703	0.00153835;
0.00108001	0.00334802	0.00151201	0.00021600	0.36835860	0.00302402	0.01101608	0.00388803	0.05666853	0.00151201	0.00997037	0.02969145	0.06879789	0.00172801	0.40726240	0.00702005	0.01183492	0.01307161;
0.01217731	0.07864641	0.00110104	0.00036379	0.00330313	0.32735670	0.20702728	0.00587868	0.00961978	0.01982888	0.02609141	0.00377500	0.02320552	0.00125833	0.05372411	0.16658783	0.05769543	0.00235938;
0.01158966	0.09243007	0.00088643	0.00036252	0.00265930	0.08779814	0.58754513	0.04112918	0.00341910	0.01556674	0.00657668	0.00303920	0.00966031	0.00101307	0.01564595	0.08153819	0.03724084	0.00189950;
0.00126096	0.00934523	0.00069654	0.00009951	0.00208961	0.00595055	0.20930364	0.73846694	0.00268665	0.00069654	0.00109456	0.00238813	0.00656735	0.00079604	0.01184114	0.00323392	0.00199011	0.00149258;
0.00126894	0.00411772	0.00177652	0.00025379	0.03396620	0.00709323	0.01294319	0.00456819	0.34319016	0.00527486	0.02169654	0.01196177	0.09568511	0.00203030	0.37020919	0.04313379	0.03282772	0.00800279;
0.01861045	0.07560729	0.00532481	0.00156602	0.00500309	0.01889205	0.03372175	0.00428836	0.01015005	0.45772277	0.00546539	0.00571781	0.08223992	0.00462787	0.04835268	0.04464292	0.17304407	0.00502272;
0.00112718	0.00650903	0.00157806	0.00022544	0.01290573	0.01759959	0.01627196	0.00405786	0.05640006	0.00515611	0.35550414	0.00541048	0.04144920	0.00180349	0.34097564	0.07467873	0.05496574	0.00338155;
0.00077208	0.00239344	0.00284852	0.00015442	0.02875077	0.00216182	0.00787521	0.00277948	0.01462390	0.00108091	0.00169857	0.58828791	0.08502244	0.00240090	0.10152035	0.00501851	0.00308832	0.14952244;
0.00152512	0.00586740	0.01333379	0.00034167	0.01609063	0.00536209	0.01457003	0.00509776	0.02089125	0.00854250	0.00560467	0.02787940	0.61026059	0.01268706	0.15517276	0.01621389	0.01906241	0.06149698;
0.00414093	0.00214412	0.23009285	0.00245938	0.00242616	0.00161744	0.00589210	0.00207957	0.00311935	0.01414586	0.00127085	0.00871487	0.22887688	0.38902763	0.02432277	0.00375477	0.00611897	0.06979551;
0.00127781	0.00431327	0.00282284	0.00025556	0.05298428	0.00810549	0.01309589	0.00460011	0.10007414	0.00523570	0.02840315	0.02025821	0.09470160	0.00247755	0.59039425	0.02877067	0.03029428	0.01193520;
0.00291526	0.02371057	0.00146868	0.00022053	0.00440603	0.07778073	0.06095675	0.00377660	0.02729465	0.00959358	0.03215047	0.00503546	0.03339750	0.00167849	0.09336125	0.53406711	0.08503920	0.00314716;
0.00365923	0.02229003	0.00264742	0.00055223	0.01093376	0.02646834	0.03711365	0.00530940	0.03266239	0.06169847	0.02733625	0.00707920	0.06610648	0.00265370	0.14344837	0.12515994	0.42025863	0.00462250;
0.00079638	0.00246879	0.01608859	0.00015928	0.01568097	0.00222987	0.00812311	0.00286698	0.01338082	0.00314790	0.00175204	0.08879618	0.31848000	0.01715142	0.08824643	0.00517649	0.00407240	0.41138235];
   
%%some related matrix useful when modeling the dispersal process
ATR=DISP;
%%ATR2 is useful for dispersers only
ATR2=ATR;
for i=1:NumPop  
   if (ATR(i,i)==1)
      ATR2(i,:)=zeros(1,NumPop);
   else
      ATR2(i,i)=0; 
   	ATR2(i,:)=ATR2(i,:)/sum(ATR2(i,:)); end;
end;


%%%Set the values of vital rates of every local population
%non adult survivals
S=[0.480265629	0.573883442	0.573883442	0.854632704;
0.480265629	0.573883442	0.573883442	0.849481871;
0.480265629	0.573883442	0.573883442	0.823897173;
0.480265629	0.573883442	0.573883442	0.846638085;
0.662946429	0.719975512	0.719975512	0.877612707;
0.480265629	0.573883442	0.573883442	0.809977369;
0.480265629	0.573883442	0.573883442	0.829643268;
0.480265629	0.573883442	0.573883442	0.821163142;
0.662946429	0.719975512	0.719975512	0.861905748;
0.480265629	0.573883442	0.573883442	0.842197139;
0.480265629	0.573883442	0.573883442	0.833061745;
0.662946429	0.719975512	0.719975512	0.874833159;
0.480265629	0.573883442	0.573883442	0.861905748;
0.480265629	0.573883442	0.573883442	0.823897173;
0.662946429	0.719975512	0.719975512	0.861905748;
0.480265629	0.573883442	0.573883442	0.809977369;
0.480265629	0.573883442	0.573883442	0.842197139;
0.662946429	0.719975512	0.719975512	0.874833159];
%%non-adult survivals to be used in SCENARIO 1
%S=[0.480265629	0.573883442	0.573883442	0.854632704;
%0.480265629	0.573883442	0.573883442	0.849481871;
%0.480265629	0.573883442	0.573883442	0.823897173;
%0.480265629	0.573883442	0.573883442	0.846638085;
%0.480265629	0.573883442	0.573883442	0.877612707;
%0.480265629	0.573883442	0.573883442	0.809977369;
%0.480265629	0.573883442	0.573883442	0.829643268;
%0.480265629	0.573883442	0.573883442	0.821163142;
%0.480265629	0.573883442	0.573883442	0.861905748;
%0.480265629	0.573883442	0.573883442	0.842197139;
%0.480265629	0.573883442	0.573883442	0.833061745;
%0.480265629	0.573883442	0.573883442	0.874833159;
%0.480265629	0.573883442	0.573883442	0.861905748;
%0.480265629	0.573883442	0.573883442	0.823897173;
%0.480265629	0.573883442	0.573883442	0.861905748;
%0.480265629	0.573883442	0.573883442	0.809977369;
%0.480265629	0.573883442	0.573883442	0.842197139;
%0.480265629	0.573883442	0.573883442	0.874833159];
%%non-adult survivals to be used in SCENARIOS 2 and 4
%S=[0.480265629	0.573883442	0.573883442	0.854632704;
%0.480265629	0.573883442	0.573883442	0.849481871;
%0.480265629	0.573883442	0.573883442	0.823897173;
%0.480265629	0.573883442	0.573883442	0.846638085;
%0.662946429	0.719975512	0.719975512	0.877612707;
%0.480265629	0.573883442	0.573883442	0.809977369;
%0.480265629	0.573883442	0.573883442	0.829643268;
%0.480265629	0.573883442	0.573883442	0.821163142;
%0.662946429	0.719975512	0.719975512	0.861905748;
%0.480265629	0.573883442	0.573883442	0.842197139;
%0.480265629	0.573883442	0.573883442	0.833061745;
%0.662946429	0.719975512	0.719975512	0.874833159;
%0.480265629	0.573883442	0.573883442	0.843753676;
%0.480265629	0.573883442	0.573883442	0.843753676;
%0.662946429	0.719975512	0.719975512	0.843753676;
%0.480265629	0.573883442	0.573883442	0.843753676;
%0.480265629	0.573883442	0.573883442	0.843753676;
%0.662946429	0.719975512	0.719975512	0.843753676];




%adult survivals and environmental variances
SAmean=[0.915844974	0.910325218	0.882908039	0.907277748	0.940470899	0.867991242	0.889065693	0.879978186	0.923638943	0.902518724	0.892729015	0.937492268	0.923638943	0.882908039	0.923638943	0.867991242	0.902518724	0.937492268]; %% resto val%adult survivals
SAvar=[0.002660363	0.000442953	0.0030304	0.002380336	0.000882768	0.003180415	0.001281247	0.002070305	0.000622246	0.001249704	0.001656961	0.000555761	0.000622246	0.0030304	0.000622246	0.003180415	0.001249704	0.000555761];
%%adult survivals to be used in SCENARIOS 2 and 4
%SAmean=[0.915844974	0.910325218	0.882908039	0.907277748	0.940470899	0.867991242	0.889065693	0.879978186	0.923638943	0.902518724	0.892729015	0.937492268	0.904186746 0.904186746	0.904186746	0.904186746	0.904186746	0.904186746]; %% resto val%adult survivals
%SAvar=[0.002660363	0.000442953	0.0030304	0.002380336	0.000882768	0.003180415	0.001281247	0.002070305	0.000622246	0.001249704	0.001656961	0.000555761	0.001667788	0.001667788 0.001667788	0.001667788	0.001667788	0.001667788];
SA=[];
for NP=1:NumPop
   for fx99 = 1:99
	valaux=betaval(SAmean(NP),sqrt(SAvar(NP)),rand);
   SA(NP,fx99)=valaux;
end;
SA=sort(SA')';
end;

%non-adult fertilities
 FNA=[0	0;
0.285714286	0.307692308;
0	0;
0	0;
0.285714286	0.8;
0.285714286	0.8;
0.285714286	0.4;
0.453888889	0.453888889;
0.285714286	0.470588235;
0.285714286	0.333333333;
0.285714286	0.510416667;
0.285714286	0.5;
0.285714286	0.381326619;
0	0;
0.285714286	0.381326619;
0.285714286	0.381326619;
0.285714286	0.381326619;
0.285714286	0.5];

%adult fertilities and environmental variances
FAmean=[0.76679198	0.95737991	0.60490096	0.61303571	1.34416667	0.95783265	1.12910934	0.97865651	1.42175527	1.00803070	1.20127197	0.83032823	0.93572236	0.60490096	1.16795831	1.08456128	0.78424789	0.83032823];
FAvar=[0.04105416	0.02711430	0.06547356	0.10000000	0.07348106	0.06470522	0.02451698	0.04539211	0.01617918	0.10972049	0.06075951	0.03282874	0.05510211	0.06547356	0.05510211	0.05510211	0.05510211	0.03282874];
FA=[];
for NP=1:NumPop
   for fx99 = 1:99
   valaux=stretchbetaval(FAmean(NP),sqrt(FAvar(NP)),0,2,rand);
   FA(NP,fx99)=valaux;
end;
FA=sort(FA')';
end;


%%%%%******************************************************************************
%%%%%******************************************************************************
%%%%%******************************************************************************
%%code of the simulation

rand('state',sum(100*clock)); % seed random number generator

%predefine some recipients for results
Ns=zeros(1,numreps);	
No_breed=zeros(1,numreps);
Nt=zeros(1,numreps);

for rep=1:numreps	% for each replicate, 
      disp(rep);
      n=n0;			% starting at the initial vector,
      
for t=1:tmax	% for each year,
   
%%	overall numbers of birds are stored in n and nn, in t-1 and t respectively
   
%%	numbers of birds in "territorial ages" (those that based in their age can be potentially territorial) are stored into three matrices:
%% (1) nb and nnb1 describe the numbers of territorials, in t-1 and t respectively
%% (2) no_pb_t0 and no_nnb1 describe the numbers of non-territorials that have not attempted to recruit as 
%% territorial (based in the recruitment probabilities), in t-1 and t respectively
%% (3) pb_no_bre_t0 and pb_no_bre describe the numbers of individuals that attempted to be territorial but that failed to recruit because of 
%% territory availability, in t-1 and t respectively

 			if t==1; %%this 'if' is required to create nb (number of territorial birds) and no_pb (numbers of non-territorial birds that did not attempt  
    			%%to recruit) in t==1; within this 'if' only birds in recruitable ages are considered
            %%in the model it works as if these numbers had resulted from the previous time step (t=0) which is not computed actually;
            %% because in t==1 there is no lack of territorial sites,
            %%all non-territorials in "territorial ages" are stored into no_pb_t0
            nb=zeros(NumPop,4);%%% Number of territorial birds
			for i=1:NumPop %for each local population      
         	pb_aux(i,:)=round(n(i,3:6).*RB);  %number of potential territorials based in the number of individuals in any given age-class and 
         												%the corresponding ratio of territorial birds in that age-class
         	for bckw=0:3	%to give settlement priority to older individuals
					K_aux=K(i)-sum(nb(i,:));		%an auxiliar vector that tracks the availability of territoriies
					pos=4-bckw;
					if(pb_aux(i,pos) <= K_aux) nb(i,pos)=pb_aux(i,pos);
					else nb(i,pos) = K_aux; end;
					if sum(nb(i,:))>=K(i) break;end;
            end;
         end;
         no_pb_t0=n(:,3:6)-nb; %%numbers of non-territorial birds in recruitable ages
      	end; %end if

%%estimate territorials which survive
for i=1:NumPop  
for j=1:2 %immatures is postion 1, subadults position 2, first year adults position 3, older adults position 4
   nnb1(i,j+1)=sum(rand(1,nb(i,j))<S(i,j+2));
end;
	SA_aux(i)=SA(i,round((rand*98)+1)); 	%picks a random value of survival for any given population
   ad1_nnb(i)=sum(rand(1,nb(i,3))<SA_aux(i)); %position 3 in nb (e.g. first year adult birds)
   ad2_nnb(i)=sum(rand(1,nb(i,4))<SA_aux(i)); %position 4 in nb (e.g. experienced adult birds)
	nnb1(i,4)=ad1_nnb(i)+ad2_nnb(i);   
end;

%%estimate non-territorials that did not attempt to recruit in t-1 (from recruitable age-classes) which survive
for i=1:NumPop 
for j=1:2 %immatures is postion 1, subadults position 2, first year adults position 3, older adults position 4
   no_nnb1(i,j+1)=sum(rand(1,no_pb_t0(i,j))<S(i,j+2));
end;
   ad1_no_nnb(i)=sum(rand(1,no_pb_t0(i,3))<SA_aux(i)); 
   ad2_no_nnb(i)=sum(rand(1,no_pb_t0(i,4))<SA_aux(i)); 
	no_nnb1(i,4)=ad1_no_nnb(i)+ad2_no_nnb(i);   
end;

%%estimate non-territorials that failed to recruit because of site availability in t-1 which survive
if (t>1) %in t==1 all non-breeders are stored into no_pb_t0, so if t==1 pb_no_bre is empty
for i=1:NumPop 
for j=1:2 %immatures is postion 1, subadults position 2, first year adults position 3, older adults position 4
   pb_no_bre(i,j+1)=sum(rand(1,pb_no_bre_t0(i,j))<S(i,j+2));
end;
   ad1_pb_no_bre(i)=sum(rand(1,pb_no_bre_t0(i,3))<SA_aux(i)); 
   ad2_pb_no_bre(i)=sum(rand(1,pb_no_bre_t0(i,4))<SA_aux(i)); 
	pb_no_bre(i,4)=ad1_pb_no_bre(i)+ad2_pb_no_bre(i);   
end;
else %%if t==1
  pb_no_bre=zeros(NumPop,4);
end; %end if t>1

%%estimate chicks and youngs in t-1 which survive to t (respectively, non-breeders of ages 1 year(juvenile) and 2 years(immatures) in t) 
for i=1:NumPop 
   for j=2:3
   nn(i,j)=sum(rand(1,n(i,j-1))<S(i,j-1));
end;
end;

%%fill the nn matrix with the numbers of birds in recruitable ages that are non-territorials to date
for i=1:NumPop 
   no_nnb1(i,1)=nn(i,3);
end;

%%estimate availability of sites for territorial recruitment
aval_abs=(K-sum(nnb1'));
aval_abs(find(aval_abs<0))=0;

%%%some previous calculations to later calculate the number of territorial birds
for i=1:NumPop %estimate potential territorials from birds without previous territorial experience (based in the recruitment probability) 
   for y=1:4 %for each age class
   pb(i,y)=sum(rand(1,no_nnb1(i,y))<RR(y)); %records potential territorials
end;
   no_pb(i,:)=no_nnb1(i,:)-pb(i,:); %records the number of birds in territorial age, but that will not attempt to recruit
end;

%%estimate potential philopatric individuals (pr): a fraction of potential territorials (pb) that will try to settle in their population of origin
for i=1:NumPop  
   for y=1:4
         pr(i,y)=sum(rand(1,pb(i,y))<ATR(i,i));
end;
end;

%%pb_no_bre attempt to recruit (birds that attempted to recruit in t-1 but that failed and that were already in the population where they attempt to recruit)
for i=1:NumPop 
      for bckw=0:3 %older individuals are allowed to recruit first than younger ones
         pos=4-bckw;
         if pb_no_bre(i,pos)<aval_abs(i);  %%if there is site availability for pb_no_bre
            aval_abs(i) =aval_abs(i)-pb_no_bre(i,pos); %%availability is reduced
            pb_exp(i,pos)=pb_no_bre(i,pos); %%pb_no_bre that have a site go into pb_exp
            pb_no_bre(i,pos)=0; %%and discounted from pb_no_bre
         else %if there is no enough site availability for all pb_no_bre
            pb_exp(i,pos)=aval_abs(i); %only those for which there is site availability go into pb_exp
            pb_no_bre(i,pos)=(pb_no_bre(i,pos)-aval_abs(i));   %and all others remain in pb_no_bre
            aval_abs(i)=0; %and there is no any more site availability in that population
         end; %end if
   end; end; %ends fors

%potential philopatric individuals attempt to recruit (birds that attempt to recruit for the first time in their life) and 
%potential dispersers pd (birds that will try to recruit in another population) are calculated
%if there is no site availability pr remain in the population of origin as pb_no_bre
for i=1:NumPop 
      for bckw=0:3  %older individuals are allowed to recruit first than younger ones
         pos=4-bckw;
         if pr(i,pos)<aval_abs(i);  %%if there is site availability for pr
            aval_abs(i) =aval_abs(i)-pr(i,pos); %%availability is reduced
            pd(i,pos)=pb(i,pos)-pr(i,pos); %%calculate potential dispersers
            pb_no_bre(i,pos)=pb_no_bre(i,pos); %%potential philopatric individuals non-allocated (because lack of sites)
         else
            pb_no_bre(i,pos)=pb_no_bre(i,pos)+(pr(i,pos)-aval_abs(i));   %those pr for which there is no site availability come back to pb_no_bre
            pd(i,pos)=pb(i,pos)-pr(i,pos); %%calculate potential dispersers
            pr(i,pos)=aval_abs(i); %only those individuals for which there is site availability remain in pr
            aval_abs(i)=0; %and there is no any more site availability in that population
         end; %end if
   end; end; %ends fors

%%decide where potential dispersers try to settle 
pin=zeros(NumPop,4); %%a recipient for potential inmigrants
for i=1:NumPop %for each population of origin
   if ATR(i,i)<1 %%if all individuals are philopatric it is not required to execute all this
	ATR_aux=ATR2(i,:); %%creates a vector with the probabilities of dispersing to any given population 
   ATR_aux(i)=[];  %%except the population of origin
   roulette = cumsum(ATR_aux); %%%a vector with cumulative probabilities to assing potential dispersers to destination populations
   terr_age=1:4; %older individuals are allowed to recruit first than younger ones
   back_age=terr_age(length(terr_age):-1:1);
   for y=back_age %for any given age class (in inverse order)
      v_pin_aux=zeros(1,NumPop-1); %%its shorter because the population of origin is not in the roulette
         for ii=1:pd(i,y) %for each individual of any given age and population of origin
         rnd_num=rand;
         if (rnd_num>0.99) rnd_num=0.99; end; %to avoid rnd_num takes value 1 
            pop_dest = find( rnd_num <= roulette );
		   	pop_dest = pop_dest(1);   
            v_pin_aux(pop_dest)=v_pin_aux(pop_dest)+1;
         end;
         if (i==1) %%put 0 inmigrants in the position of the population of origin
         	v_pin_aux=[0,v_pin_aux]; 
      	else
            v_pin_aux=[v_pin_aux(1:(i-1)),0,v_pin_aux(i:end)]; 
         end; 
         
         for j=1:NumPop %%for each destination population
        	if v_pin_aux(j)<aval_abs(j); %if the number of potential inmigrants is lower than site availability
            pin(j,y)=pin(j,y)+v_pin_aux(j); %fills the matrix of potential inmigrants
            aval_abs(j) =aval_abs(j)-v_pin_aux(j); %reduces site availability
            pd(i,y)=pd(i,y)-v_pin_aux(j); %and discount already dispersed birds from potential dispersers
         else
            pin(j,y)=pin(j,y)+aval_abs(j); %if there is not enough site availability only go into potential inmigrants those for which there is site availability
            pd(i,y)=pd(i,y)-aval_abs(j); %discount already dispersed birds from potential dispersers
            pb_no_bre(j,y)=pb_no_bre(j,y)+(v_pin_aux(j)-aval_abs(j)); %%inmigrants aiming to recruit for which there is no site availability go into pb_no_bre
				aval_abs(j)=0;  %and there is no any more site availability in that population
         end;
      end; %ends loop for destiny population
      end; %ends backage
      end; %ends if
end; %ends population of origin  

   
%%calculate birds without previous experience that will try to breed on each population
pb2=pr+pin+pb_exp;
%%recalculate population numbers after migration of potential breeders
new_nn=nnb1+pb2+no_pb+pb_no_bre;
nn(:,3:ageclass)=new_nn;
      
%%calculate the number of breeders
nnb=nnb1+pb2; 
%records the number of  non-breeders
no_nnb=nn(:,3:6)-nnb;			
      
%%calculate productivities
for i=1:NumPop    
     nn(i,1)=round((nnb(i,1)*(FNA(i,1)*Sr))+(nnb(i,2)*(FNA(i,2)*Sr))+(nnb(i,3)*(FA(i,round((rand*98)+1))*Sr))+(nnb(i,4)*(FA(i,round((rand*98)+1))*Sr)));
end;
         
%% records total numbers of birds         
		Npairs=sum(sum(nnb)); %records the total numbers of territorial pairs
      Npairs_pop=sum(nnb');
      N_pb_no_bre_pops=sum(pb_no_bre'); %%records the total number of potential breeders at each population that do not bred, because K
      N=sum(sum(nn));               % Sum total population size & 
      Nnonbre=N-Npairs;			%records de total number of non-breeder
      
 %% records local population fates
      pop_fate(t,rep)=Npairs;
      for i=1:NumPop %per cada poblaci      
          pop_fate_pops(t,rep,i)=Npairs_pop(i);
          pop_fate_pops_pb_no_bre(t,rep,i)=N_pb_no_bre_pops(i);
      end;
      if Npairs<=Nx break; end;     % stop if threshold is hit.
            
  %%%replace old vectors with newones
      nb=nnb;
      no_nb=no_nnb;            
      n=nn;                    
   
	   pb_no_bre_t0=pb_no_bre; %keep separate the count of potential territorial birds that did not find a site to recruit 
	   no_pb_t0=no_pb;			%from those birds of 'territorial ages' that did not attempt to recruit
            
  %reset other recipients
      nn=[];
      nnb=[];
      no_nnb=[];
      nnb1=[];
      no_nnb1=[];
      pb=[];
      no_pb=[];
      pr=[];
      pd=[];
      pin=[];
      pb_no_bre=[];
      pb_exp=[];
            
end; %%%%%%%%ends for t

% Store final population size
Ns(rep)=Npairs;                   
No_breed(rep)=Nnonbre;
Nt(rep)=N;

end; % ends for rep

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%ends the code of the simulation

 %%Get average population fate 
 inv_pop_fate=sort(pop_fate');
 mean_pop_fate=[];
 mean_pop_fate(1,:)=inv_pop_fate(round((numreps/100)*2.5),:);
 mean_pop_fate(2,:)=mean(inv_pop_fate);
 mean_pop_fate(3,:)=inv_pop_fate(round((numreps/100)*97.5),:);

 %%%Estimate local population lambdas; only considers the period before extinction, irrespectively if after the population is recolonized
  lambdas_pop=zeros(NumPop,4);
    for i=1:NumPop
	ld_aux1 =zeros(1,numreps); %recipient for lambdas
	size_aux=size(pop_fate_pops(:,:,i));  %auxiliar vector for local population fates
		for z=1:size_aux(2)
   	vaux=pop_fate_pops(:,z,i)'; %another auxiliar recipient for local population fates
   	if sum(vaux==0)>0 %if extincition is done, then only consider the period before extinction
      vaux2=vaux(1:min(find(vaux==0)))+1; 
   	else
      vaux2=vaux;
   	end;
   	l_vaux=length(vaux2);
      	for q=1:(l_vaux-1)
          ld_aux2(q)=vaux2(q+1)./vaux2(q); %save lambdas for one year intervals in recipient 2
    		end;
    	ld_aux1(z)=gmean(ld_aux2); %geometric mean of lambdas (for each replicate)
    	ld_aux2=[]; %reset recipient 2
 		end;
   ld_aux1=sort(ld_aux1); %sort the vector with the values of lambdas for each replicate
          
 lambda=mean(ld_aux1); %mean lambda
 ic95_inf=ld_aux1(round((numreps/100)*2.5)); %95% percetile range
 ic95_sup=ld_aux1(round((numreps/100)*97.5));
 lambda_median=median(ld_aux1); %median
 
 lambdas_pop(i,1)=lambda; %records lambda summaries
 lambdas_pop(i,2)=ic95_inf;
 lambdas_pop(i,3)=ic95_sup;
 lambdas_pop(i,4)=lambda_median;
 end; %ends initial for

%%%Estimate overall population lambda
ld_aux1 =zeros(1,numreps); %recipient for lambdas
size_aux=size(pop_fate);
   for z=1:size_aux(2)
      for q=1:(size_aux(1)-1)
          if pop_fate(q+1,z)>=Nx
          ld_aux2(q)=pop_fate(q+1,z)./pop_fate(q,z); %save lambdas for one year intervals in recipient 2
          end;
    end;
    ld_aux1(z)=gmean(ld_aux2);
    ld_aux2=[]; %reset recipient 2
 end;
    ld_aux1=sort(ld_aux1);
 
 lambda=mean(ld_aux1);
 ic95_inf=ld_aux1(round((numreps/100)*2.5));
 ic95_sup=ld_aux1(round((numreps/100)*97.5));
 disp('lambda')
 disp(lambda)
 disp('lower 95CI')
 disp(ic95_inf)
 disp('upper 95CI')
 disp(ic95_sup)
 

%%%%SAVE MAIN RESULTS
%save MET18_CONS_POW pop_fate mean_pop_fate pop_fate_pops lambda ic95_inf ic95_sup lambdas_pop
%save MET18_CONS_EXP pop_fate mean_pop_fate pop_fate_pops lambda ic95_inf ic95_sup lambdas_pop
  
 %Have a look on the overall trend
 aux_axis=[1:tmax];
 figure(1)
 plot(aux_axis,mean_pop_fate([1 3],:)','b--',aux_axis,mean_pop_fate(2,:),'b-')
 axis([0 tmax 1 1200])
 xlabel('Time','FontSize',14)
 ylabel('No. territorial pairs','FontSize',14)

  
 %and on local trends
 inv_pop_fate=sort(pop_fate_pops(:,:,17)');
 mean_pop_fate_p=[];
 mean_pop_fate_p(1,:)=inv_pop_fate(round((numreps/100)*2.5),:);
 mean_pop_fate_p(2,:)=mean(inv_pop_fate);
 mean_pop_fate_p(3,:)=inv_pop_fate(round((numreps/100)*97.5),:);
 figure(2)
 plot(aux_axis,mean_pop_fate_p([1 3],:)','b--',aux_axis,mean_pop_fate_p(2,:),'b-')
 axis([0 tmax 0 100])
 xlabel('Time','FontSize',14)
 ylabel('No. territorial pairs','FontSize',14)

